from django import template
from django.db import models

register = template.Library()


@register.inclusion_tag("category/category_plot.html")
def category_plot(transactions):
    categories = (
        transactions.filter(category__budget=True)
        .values("category", "category__name", "category__icon")
        .annotate(
            sum=models.Sum("value"),
            sum_m=models.Sum("value", filter=models.Q(value__lt=0)),
            sum_p=models.Sum("value", filter=models.Q(value__gt=0)),
        )
        .order_by("-sum")
    )
    return {
        "categories": categories,
        "max": max(
            categories.aggregate(
                max=models.Max("sum_p", default=0),
                min=models.Min("sum_m", default=0),
            ).values(),
        ),
    }
